@@ -10,8 +10,7 @@ pub use new::*;
 pub use props::*;
 
 use crate::Node;
-use rand_xoshiro::Xoshiro256StarStar;
-use rustc_hash::FxHashMap as HashMap;
+use rand_xoshiro::Xoshiro256Plus;
 use serde::{Deserialize, Serialize};
 use std::cell::RefCell;
 
@@ -19,23 +18,25 @@ use std::cell::RefCell;
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Network {
     /// The main data structure.
-    nodes: HashMap<usize, Node>,
+    /// # Important
+    /// This vector **must be sorted** at **all times**!
+    nodes: Vec<Node>,
     /// The model used to initialize links between nodes.
     model: Model,
     /// The distribution followed by the link weights.
     weight: Weight,
     /// The network's randomness source
-    rng: RefCell<Xoshiro256StarStar>,
+    rng: RefCell<Xoshiro256Plus>,
     /// The network size (total number of nodes in the network)
     size: usize,
-    /// The network integrity, ie. if nodes[i].index() == i.
-    integrity_kept: bool,
+    /// The network indexing integrity, ie. whether nodes[i].index() == i.
+    indexing_ok: bool,
 }
 
 /// Enables easy non-mutable access to the nodes using the indexing operator.
 impl std::ops::Index<usize> for Network {
     type Output = Node;
     fn index(&self, idx: usize) -> &Self::Output {
-        &self.nodes[&idx]
+        &self.nodes[idx]
     }
 }
